@@ -54,6 +54,7 @@
 #include <KProcess>
 #include <KRecentFilesAction>
 #include <KApplication>
+#include <KToggleFullScreenAction>
 #include <kabstractfilewidget.h>
 #include <analitzaplot/plotsfactory.h>
 
@@ -106,16 +107,23 @@ KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
 {
 	resize(900, 500);
 	
-	m_tabs = new QTabWidget(this);
+	m_tabs = new QTabWidget;
 	setCentralWidget(m_tabs);
 	
 	setStatusBar(new KStatusBar(this));
 	setMenuBar(new KMenuBar(this));
 	
+	KToggleFullScreenAction* fullScreenAction = KStandardAction::fullScreen(this, SLOT(fullScreen(bool)), this, this);
+	
 	QMenu* g_menu = menuBar()->addMenu(i18n("Session"));
 	g_menu->addAction(KStandardAction::openNew(this, SLOT(newInstance()), this));
+	g_menu->addAction(fullScreenAction);
 	g_menu->addAction(KStandardAction::quit(this, SLOT(close()), this));
 	
+	QToolButton* fullScreenButton = new QToolButton(this);
+	fullScreenButton->setDefaultAction(fullScreenAction);
+	m_tabs->setCornerWidget(fullScreenButton);
+	
 	m_status = new QLabel(this);
 	statusBar()->insertWidget(0, m_status);
     menuBar()->addMenu("|")->setEnabled(false);
@@ -585,28 +593,34 @@ void KAlgebra::saveGraph()
 	delete dialog;
 }
 
+void menuEnabledHelper(QMenu* m, bool enabled)
+{
+	m->setEnabled(enabled);
+	foreach(QAction* action, m->actions()) {
+		action->setEnabled(enabled);
+	}
+}
+
 void KAlgebra::tabChanged(int n)
 {
 	c_dock_vars->hide();
 	b_dock_funcs->hide();
 	d_dock->hide();
 	
-	c_menu->setEnabled(false);
-	b_menu->setEnabled(false);
+	menuEnabledHelper(c_menu, n==0);
+	menuEnabledHelper(b_menu, n==1);
 #ifdef HAVE_OPENGL
-	t_menu->setEnabled(false);
+	menuEnabledHelper(t_menu, n==2);
 #endif
 	m_status->clear();
 	
 	switch(n) {
 		case 0:
-			c_menu->setEnabled(true);
 			c_dock_vars->show();
 			c_dock_vars->raise();
 			c_exp->setFocus();
 			break;
 		case 1:
-			b_menu->setEnabled(true);
 			b_dock_funcs->show();
 			b_dock_funcs->raise();
 			
@@ -616,7 +630,6 @@ void KAlgebra::tabChanged(int n)
 			break;
 #ifdef HAVE_OPENGL
 		case 2:
-			t_menu->setEnabled(true);
 			t_exp->setFocus();
 			break;
 #endif
@@ -690,4 +703,17 @@ void KAlgebra::dictionaryFilterChanged(const QString&)
 		d_list->setCurrentIndex(d_list->model()->index(0,0));
 }
 
-#include "kalgebra.moc"
+void KAlgebra::fullScreen(bool isFull)
+{
+	m_tabs->setDocumentMode(isFull);
+	m_tabs->setTabEnabled(3, !isFull);
+	if(isFull) {
+		hide();
+		m_tabs->setParent(0);
+		setCentralWidget(0);
+		m_tabs->showFullScreen();
+	} else {
+		setCentralWidget(m_tabs);
+		show();
+	}
+}
